@@ -77,7 +77,7 @@ int bug_380824 (int arg) {
  *
  * Returns: result
  */
-struct bug *
+struct bug_411739_rettype *
 bug_411739 (void) {
   return NULL;
 }
@@ -426,3 +426,26 @@ void deprecation_notice(void)
 {
 }
 
+/**
+ * bug_741941:
+ * @object: the object
+ * @par: parameter
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=741941
+ */
+void bug_741941(void *object, void *par)
+{
+}
+
+/**
+ * bug_732689:
+ * @spec: the string specifying the color.
+ *
+ * Parses a textual specification of a color and fill in the
+ * <structfield>red</structfield>, <structfield>green</structfield>,
+ * and <structfield>blue</structfield> fields of a color.
+ **/
+void
+bug_732689 (const gchar *spec)
+{
+}
\ No newline at end of file
